.. _gmf:

Magnetic field models for the Milky Way
---------------------------------------

At the moment, two models of the coherent component of Galactic magnetic field are available.
Typically, the coherence length of the turbulent component is too small to induce large scale photon-ALP oscillations
at gamma-ray energies and hence only the coherent components are considered here.

The two models are the ones described in detail in [Pshirkov2011]_ and [Jansson2012]_.
For the Jansson & Farrar model [Jansson2012]_, also the updates from measurements with the Planck satellite
are available [Planck2016]_.

Reference / API
^^^^^^^^^^^^^^^

.. automodule:: gammaALPs.bfields.gmf
    :members:
    :undoc-members:
    :show-inheritance:
    :inherited-members:
